/* BioJavaUtils.java
 *
 * created: Fri Nov 28 2003
 *
 * This file is part of Artemis
 * 
 * Copyright (C) 2003  Genome Research Limited
 * 
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation; either version 2
 * of the License, or (at your option) any later version.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
 *
 * $Header:$
 */

package diana.components;

import org.biojava.bio.seq.io.SequenceFormat;


/**
 *  BioJavaUtils class
 *
 *  @author Kim Rutherford <kmr@sanger.ac.uk>
 *  @version $Id:$
 **/

public class BioJavaUtils {
  /**
   *  Handle the -biojava option
   **/
  private void handleBioJava (final String [] args) {
    if (args.length == 3) {
      final String class_name = args[1];
      final String location = args[2];

      final Document location_document =
        DocumentFactory.makeDocument (location);

      try {
        final SequenceFormat sequence_format =
          (SequenceFormat) Class.forName (class_name).newInstance ();

        final uk.ac.sanger.pathogens.embl.BioJavaEntry emblEntry =
          new uk.ac.sanger.pathogens.embl.BioJavaEntry (location_document,
                                                        sequence_format);

        final Entry new_entry = new Entry (emblEntry);

        final EntryEdit new_entry_edit = makeEntryEdit (new_entry);

        new_entry_edit.setVisible (true);
      } catch (IllegalAccessException e) {
        new MessageDialog (this, "cannot create class: " + class_name +
                           " - IllegalAccessException");
      } catch (ClassNotFoundException e) {
        new MessageDialog (this, "cannot find class: " + class_name);
      } catch (ClassCastException e) {
        new MessageDialog (this, class_name + " is not a sub-class of " +
                           "SequenceFormat");
      } catch (IOException e) {
        new MessageDialog (this, "I/O error while reading from " +
                           location + ": " + e.getMessage ());
      } catch (NoSequenceException e) {
        new MessageDialog (this, location + " contained no sequence");
      } catch (InstantiationException e) {
        new MessageDialog (this, "cannot instantiated " + class_name + ": " +
                           e.getMessage ());
      } catch (OutOfRangeException e) {
        new MessageDialog (this, "read failed: one of the features in " +
                           location +
                           " has an out of range location: " +
                           e.getMessage ());
      }
    } else {
      new MessageDialog (this, "the -biojava option needs two arguments");
    }
  }
}
